.. Django Envie documentation master file, created by
   sphinx-quickstart on Thu Sep 17 21:29:31 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
========================================
Welcome to Django Envie's documentation!
========================================

Django Envie is a way to make use of .env.py files that contain configuration that you don't want exposed in your application settings.

Contents:

.. toctree::
   :maxdepth: 2

   01-testing

   02-formatting

   03-importing
